FunctionRegistry

Struct FunctionRegistry 

pub struct FunctionRegistry { /* private fields */ }
Registry for managing function availability at runtime.

Implementations

Source

impl FunctionRegistry

pub fn new() -> Self

Creates a new empty registry.

pub fn register_all(&mut self) -> &mut Self

Registers all available functions.

pub fn register_category(&mut self, category: Category) -> &mut Self

Registers all functions in a category.

pub fn disable_function(&mut self, name: &str) -> &mut Self

Disables a specific function (for ACLs).

pub fn enable_function(&mut self, name: &str) -> &mut Self

Enables a previously disabled function.

pub fn is_enabled(&self, name: &str) -> bool

Checks if a function is enabled.

pub fn get_function(&self, name: &str) -> Option<&FunctionInfo>

Gets info about a specific function.

pub fn functions(&self) -> impl Iterator<Item = &FunctionInfo>

Iterates over all enabled functions.

pub fn functions_in_category( &self, category: Category, ) -> impl Iterator<Item = &FunctionInfo>

Iterates over functions in a specific category.

pub fn categories(&self) -> impl Iterator<Item = &Category>

Gets all registered categories.

pub fn len(&self) -> usize

Gets count of enabled functions.

pub fn is_empty(&self) -> bool

Checks if registry is empty.

pub fn functions_with_feature( &self, feature: Feature, ) -> impl Iterator<Item = &FunctionInfo>

Iterates over functions with a specific feature tag.

pub fn spec_function_names(&self) -> impl Iterator<Item = &'static str> + '_

Gets all spec-only (standard JMESPath) function names.

pub fn is_spec_function(&self, name: &str) -> bool

Checks if a function is a standard JMESPath spec function.

pub fn get_function_by_name_or_alias(&self, name: &str) -> Option<&FunctionInfo>

Gets function info by name or alias.

pub fn all_aliases( &self, ) -> impl Iterator<Item = (&'static str, &'static str)> + '_

Gets all aliases as (alias, canonical_name) pairs.

pub fn apply(&self, runtime: &mut Runtime)

Applies the registry to a runtime, registering extension functions.

This calls each category’s register_filtered function to add enabled extension functions to the runtime. Standard functions are registered separately via runtime.register_builtin_functions().